@@ -453,6 +453,7 @@ class Download:
             percentage_previous = -1
 
             file_path = self._path + '/dvl/' + datetime.now().strftime('%y%m%d_%H%M%S')
+            self.messages.write_message('Downloading data to: {}'.format(file_path))
             Path(file_path).mkdir(parents=True, exist_ok=True)
             with open(file_path + '/dvl_data.bin', 'wb') as file, open(file_path + '/dvl_crc_fails.bin', 'wb') as fail_file:
 
@@ -551,11 +552,14 @@ class Download:
 
             #folder = self.logger.start()
             file_path = self._path + '/nucleus/' + datetime.now().strftime('%y%m%d_%H%M%S')
+            self.messages.write_message('Downloading data to: {}'.format(file_path))
             Path(file_path).mkdir(parents=True, exist_ok=True)
+
             with open(file_path + '/get_all.txt', 'w') as file:
                 file.writelines(get_all.decode())
 
             with open(file_path + '/nucleus_data.bin', 'wb') as file:
+                file.write(get_all)
                 percentage_previous = -1
                 downloaded_bytes = 0
                 for index in range(download_parameters['sa'], download_parameters['end'], self.PACKET_LENGTH):
@@ -565,6 +569,8 @@ class Download:
                     downloaded_bytes += len(package)
                     percentage = downloaded_bytes * 100 / (download_parameters['end'] - download_parameters['sa'])
                     if percentage > percentage_previous + 1:
+                        if percentage > 99:
+                            percentage = 100
                         self.progress_bar(percentage, 100)
                         percentage_previous = int(percentage)
 
@@ -575,7 +581,120 @@ class Download:
 
                     #self.parser.add_data(package)
 
-                self.progress_bar(100, 100)
+                #self.progress_bar(100, 100)
                 #self.logger.stop()
 
         return status
+
+    def convert_nucleus_data(self, path) -> bool:
+
+        if not Path(path).is_file():
+            self.messages.write_warning('selected file path is not a file')
+            return False
+
+        path_folder = Path(path).parent
+
+        self.logger.set_path(path=path_folder + '/nucleus_converted')
+
+        folder = self.logger.start(_converting=True)
+
+        # TODO: THIS RELIES ON GET ALL DATA BEING IN THE SAME FILE AS BINARY DATA
+        with open(path, 'rb') as raw_file:
+
+            raw_file.seek(0, 2)
+            file_length = raw_file.tell()
+            raw_file.seek(0, 0)
+
+            '''
+            get_all = b''
+            get_all_detected = False
+            for _ in range(3000):
+
+                #byte = raw_file.read(1)
+                get_all += raw_file.read(1)
+
+                #if byte == b'':
+                #    self.messages.write_warning(message='Reached end of file without detecting GET_ALL')
+                #    return False
+
+                #get_all += byte
+
+                #if len(get_all) > 3000:
+                #    self.messages.write_message(message='Did not find GEL_ALL info at the start of the binary file. proceeding with parsing')
+                #    break
+
+                if b'\r\n\x00' in get_all:
+                    get_all_detected = True
+                    break
+
+            else:
+                self.messages.write_message(message='Did not find GEL_ALL info at the start of the binary file. proceeding with data parsing')
+
+            if get_all_detected:
+                ascii_queue_status = self.parser.get_queuing()['ascii']
+                self.parser.set_queuing(ascii=True)
+
+                self.parser.add_data(get_all)
+                nucleus_get_all = None
+
+                while True:
+                    data = self.parser.read_ascii()
+
+                    if data is None:
+                        break
+                    elif data['bytes'][0] == 0x20:
+                        nucleus_get_all = data['bytes'][1:].rstrip(b'\x00')
+
+                self.parser.set_queuing(ascii=ascii_queue_status)
+
+                if nucleus_get_all is not None:
+                    with open(folder + '/get_all.txt', 'w') as get_all_file:
+                        get_all_file.writelines(nucleus_get_all.decode())
+                else:
+                    self.messages.write_warning('could not retrieve GET_ALL data from file')
+                    return False
+
+            else:
+                self.parser.add_data(get_all)
+            '''
+
+            packet_queue_status = self.parser.get_queuing()['packet']
+            ascii_queue_status = self.parser.get_queuing()['ascii']
+            self.parser.set_queuing(packet=False, ascii=True)
+
+            get_all_detected = False
+            percentage_previous = -1
+
+            while True:
+                data = raw_file.read(1)
+
+                percentage = raw_file.tell() * 100 / file_length
+                if percentage > percentage_previous + 1:
+                    if percentage > 99:
+                        percentage = 100
+                    self.progress_bar(percentage, 100)
+                    percentage_previous = int(percentage)
+
+                if data == b'':
+                    break
+
+                self.parser.add_data(data)
+
+                if not self.parser.ascii_queue.empty() and not get_all_detected:
+                    data = self.parser.read_ascii()
+
+                    if data['bytes'][0] == 0x20:
+                        get_all = data['bytes'][1:].rstrip(b'\x00')
+                        with open(folder + '/get_all.txt', 'w') as get_all_file:
+                            get_all_file.writelines(get_all.decode())
+
+                        get_all_detected = True
+
+            if not get_all_detected:
+                self.messages.write_warning('GEL_ALL data was not detected in binary file!')
+
+            self.logger.stop()
+
+            self.parser.set_queuing(packet=packet_queue_status, ascii=ascii_queue_status)
+
+        return True
