@@ -343,6 +343,22 @@ class App(cmd2.Cmd):
         else:
             self.nucleus_driver.messages.write_warning('Failed to completely download data')
 
+    convert_nucleus_data_parser = Cmd2ArgumentParser(description='Nucleus binary file path')
+    convert_nucleus_data_parser.add_argument('path', help='Select path for nucleus binary file', completer=cmd2.Cmd.path_complete)
+
+    @with_argparser(convert_nucleus_data_parser)
+    @with_category(CMD_CAT_DOWNLOAD)
+    def do_convert_nucleus_data(self, convert_nucleus_data_args):
+
+        path = convert_nucleus_data_args.path
+
+        status = self.nucleus_driver.convert_nucleus_data(path=path)
+
+        if status:
+            self.nucleus_driver.messages.write_message('Successfully converted data')
+        else:
+            self.nucleus_driver.messages.write_warning('Failed to completely convert data')
+
     list_files_parser = Cmd2ArgumentParser(description='List Nucleus or DVL files')
     list_files_parser.add_argument('data_type', choices=['nucleus', 'dvl'], help='List Nucleus data or DVL diagnostics data')
 
